# The number_comparator package.

# It can compare if a number is prime, pair, etc.

from number_comparator.comparisons import *
from number_comparator.operations import *
from number_comparator.data.first_prime import *

__author__ = "Diego Ramirez <dr01191115@gmail.com> @DiddiLeija"
__version__ = "0.0.5"
__license__ = "MIT"
